@@ -1,16 +1,17 @@
 #!/bin/bash
-#this is the shell script executes the program (ChemConsole v-0.3)
+#this is the shell script executes the program (ChemConsole v-0.4)
 #Edit this to work with you system
 #
 
 #The location of JRE directory 
-J_HOME=/usr/local/jdk117
+J_HOME=/usr/lib/java
 
 #The location the ChemConsole directory
-C_HOME=/home/nath/Jfc/Chemc-0.3
+C_HOME=/home/nathan/Jfc/Chemc-0.4
 
 #The location of the Swing directory
-S_HOME=/usr/local/swing-1.0.3
+S_HOME=/usr/lib/swing1
 
+#Don't edit beyond this point unless you know what you are doing.
 jre -classpath $J_HOME/lib/classes.zip:$C_HOME/ChemConsole.jar:$C_HOME/rmic:$S_HOME/swingall.jar ChemConsole
 
