@@ -6,7 +6,7 @@
  * Created: Thu Apr 22 13:53:20 1999
  *
  * @author Nathan Stevens
- * @version 0.3;
+ * @version 0.4 July-99
  */
 import java.awt.*;
 import java.awt.event.*;
@@ -58,9 +58,9 @@ public class BabelPanel extends JPanel implements ActionListener,
       setLayout(new BorderLayout());
           
       
-      // set the border for main panel and inner panels
+      /** set the border for main panel and inner panels
       SoftBevelBorder mainb = new SoftBevelBorder(SoftBevelBorder.RAISED);
-      setBorder(mainb);
+      setBorder(mainb); */
 
       // Line and titled borders
       TitledBorder border;
@@ -76,6 +76,7 @@ public class BabelPanel extends JPanel implements ActionListener,
 	{
            // put a nice picture in center grear
 	}
+
       // add title in north potion of panel
       Font font = new Font("Times-Roman", Font.ITALIC, 14);
       JLabel name = new JLabel("Babel v1.6", JLabel.CENTER);
@@ -116,9 +117,9 @@ public class BabelPanel extends JPanel implements ActionListener,
       // add pan1 to main panel
       add(pan1, "West");
 
-      /** add the output file panel basically the same as out file format
-       *
-       */
+      /** 
+       * Add the output file panel basically the same as out file format
+       **/
       JPanel pan2  = new JPanel();
       pan2.setLayout(new BorderLayout());
 
@@ -151,7 +152,8 @@ public class BabelPanel extends JPanel implements ActionListener,
       // add pan2 to main panel
       add(pan2, "East");
      
-      /** The file input  panel. this is were the name of the file is entered
+      /** 
+       * The file input  panel. this is were the name of the file is entered
        * it will consist of Jlabels and JText and Jbuttons
        **/
       JPanel pan3  = new JPanel();
@@ -291,7 +293,7 @@ public class BabelPanel extends JPanel implements ActionListener,
       pan4.add(pan4B,"South");
         
       add(pan4, "South");
-
+              
       // Read in the config file
       ReadCfg();
       upDate();
@@ -312,9 +314,7 @@ public class BabelPanel extends JPanel implements ActionListener,
               while(!f.eof())
 		{
                   ServerList.addElement(f.readString());
-		}
-	      // add code to set the list of servers in the networkpanel
-              
+		}         
 	    }
           f.close(); 
 	} 
@@ -493,7 +493,6 @@ public class BabelPanel extends JPanel implements ActionListener,
 	{
            delHydrogen();
 	} 
-      // add code
     }
   
   public void valueChanged(ListSelectionEvent e)
@@ -543,15 +542,43 @@ public class BabelPanel extends JPanel implements ActionListener,
       
       intype  = tf1.getText();
       infile  = tf3.getText();
-      keyw1   =  tf5.getText();
+      keyw1   = tf5.getText();
       outtype = tf2.getText();
       outfile = tf4.getText();
       keyw2   = tf6.getText();      
       
       if(intype.length() != 0 && infile.length() != 0 && outtype.length() != 0  && outfile.length() != 0)
 	      {
-                ChemAppThread app = new BabelApp(this);
-                app.start();
+                BabelApp bApp = new BabelApp();
+		// Now set all the public variables in the babelApp.
+		// This was done to separate the Gui component from
+		// non giu component.
+
+                bApp.Mode = Mode;
+
+                if(Mode.equals("local"))
+		  {
+                    bApp.BABEL_BIN = command;
+                  }
+                else
+		  {
+                    bApp.hostname = np.getServer();
+                    bApp.isRetrieve = np.isRetrieve();
+                    bApp.infile2 = infile;  
+		  }     
+
+                bApp.infile = getInfile();
+                bApp.outfile = outfile;
+                bApp.inputType = intype;
+                bApp.outputType = outtype;
+                bApp.keyw1 = keyw1;
+                bApp.keyw2 = keyw2;
+                bApp.rnum = rn;
+                bApp.adh = adh;
+	   
+		// Call the threads run methods
+                bApp.start();
+                
 	      }
             else
 	      { 
@@ -672,18 +699,10 @@ public class BabelPanel extends JPanel implements ActionListener,
     }
   
   /**
-   * This methods are to provide access to the private variable of the this
+   * This method are to provide access to the private variable of the this
    * Class. This was done so that I can eventually turn this app into a 
    * Java Bean.
    **/
-  public String getMode()
-    {
-      return Mode;
-    }
-  public String getIntype()
-    {
-      return intype;
-    }
   public String getInfile()
     {
       if(fdir != null)
@@ -694,51 +713,7 @@ public class BabelPanel extends JPanel implements ActionListener,
 	{
           return infile;
 	}
-    }
-  public String getKeyw1()
-    {
-      return keyw1;
-    }
-  public String getOuttype()
-    {
-      return outtype;
-    }
-  public String getOutfile()
-    {
-      return outfile;
-    }
-  public String getKeyw2()
-    {
-     return keyw2;
-    }
-  public String getRn()
-    {
-      return rn;
-    }
-  public String getAdh()
-    {
-      return adh;
-    }
-  public String getCommand()
-    {
-      return command;
-    }
-  public String getServer()
-    {
-      String selServer = np.getServer();
-
-      return selServer;
-    }
-  public boolean isRetrieve()
-    {
-      return np.isRetrieve();
-    }
-
-  // This method used in network mode only  
-  public String getInfile2()
-    {
-      return infile;
-    }
+    }  
 }
 
 
