@@ -1,9 +1,9 @@
 
 /**
- * Class Dedit is a class that allow the user of the program Phem so that 
+ * Class Dedit is a class that allow the users so that 
  * They can edit the input files using the build in editor
  *@author Nathan Stevens
- *@version 0.2
+ *@version 0.4 July-99
  */
 
 import java.awt.*;
@@ -24,19 +24,19 @@ public class DataFileEditorPanel extends JPanel implements ActionListener
   private String data;
   private Font f;
   private File file;
-  private ChemToolFrame win;
+  private ChemDialog win;
+  private ChemMessage m;
+  private fDialog fd;
+  private JButton bt1, bt2, bt3, bt4;
 
   // Constructors
-  public DataFileEditorPanel(File file)
+  public DataFileEditorPanel()
     {
-      this("Date File", file);
+      this("Date File");
     }
 
-  public DataFileEditorPanel(String title, File file)
-    { 
-      // create the file object
-      this.file = file;
-      
+  public DataFileEditorPanel(String title)
+    {    
       // use a Border layout
       setLayout(new BorderLayout());
       setLocation(50, 70);
@@ -60,36 +60,43 @@ public class DataFileEditorPanel extends JPanel implements ActionListener
 
       add(areaScrollPane, "Center");
       
-      // Call the method that reads the text from the "file" object
-      ReadText();
-
       // create a button panel and add the Panel to the frame
       JPanel bp  = new JPanel();
-      FlowLayout ly = new FlowLayout(FlowLayout.CENTER, 100, 5);      
-      bp.setLayout(ly); 
+      FlowLayout ly = new FlowLayout(FlowLayout.CENTER, 50, 5);      
+      bp.setLayout(ly);
 
-      // Create the button and add it to panel
-      JButton button; 
+      // set the border
+      TitledBorder border2 = new TitledBorder("File");
+      border2.setTitlePosition(TitledBorder.TOP);
+      border2.setTitleJustification(TitledBorder.CENTER);
+      bp.setBorder(border2); 
+
+      // Create the button and add it to panel 
+
+      bt1 = new JButton("Open");
+      bt1.addActionListener(this);
+      bt1.setActionCommand("open");
+      bp.add(bt1);      
       
-      button = new JButton("Save");
-      button.addActionListener(this);
-      button.setActionCommand("Save");
-      bp.add(button);
+      bt2 = new JButton("Save");
+      bt2.addActionListener(this);
+      bt2.setActionCommand("save");
+      bp.add(bt2);
      
-      button = new JButton("Clear");
-      button.addActionListener(this);
-      button.setActionCommand("Clear");
-      bp.add(button);
+      bt3 = new JButton("Clear");
+      bt3.addActionListener(this);
+      bt3.setActionCommand("clear");
+      bp.add(bt3);
      
-      button = new JButton("Close");
-      button.addActionListener(this);
-      button.setActionCommand("close");
-      bp.add(button);
+      bt4 = new JButton("Close");
+      bt4.addActionListener(this);
+      bt4.setActionCommand("close");
+      bp.add(bt4);
      
       // Add the buttons to panel
       add(bp, "South");
       
-      win = new ChemToolFrame(title + " File " + "(" + file + ")", this);
+      win = new ChemDialog(title, this);
     }
     
   // Handle the events
@@ -98,23 +105,67 @@ public class DataFileEditorPanel extends JPanel implements ActionListener
       String cmd;
       cmd = e.getActionCommand();
       
-      if(cmd.equals("Save"))
+      if(cmd.equals("open"))
 	{
-          SaveText();
+          getFile();
+	}
+        
+      else if (cmd.equals("save"))
+	{
+          saveText();
 	}
       else if(cmd.equals("close"))
 	{
-          win.setVisible(false);
-          win.dispose();
+          win.close();
 	}
-      else if(cmd.equals("Clear"))
+      else if(cmd.equals("clear"))
 	{
           textArea.setText("");
 	}
     }
 
+  // Metohd to get a file from file dialog
+  private void getFile()
+    {
+      // make a filedialog
+      fd  = new fDialog(this, "Input File name");
+      fd.setBackground(getPanelColor());
+      fd.show();
+
+      String fname = fd.getFile();
+      String fdir = fd.getDirectory();
+
+      // create file
+      File tmpf = new File(fdir + fname);
+      
+      // call the setFile Method
+      setFile(tmpf);
+    }
+  
+  // Method to set the file to be displayed
+  public void setFile(File infile)
+    {
+      if(infile.isFile())
+	{
+          this.file = infile;
+          readText();
+	}
+      else
+	{
+          m = new ChemMessage(this);
+          m.errPrint("Can't find file " + infile + ".", "File Error");
+	}
+    }
+
+  // Method to set text area editable or not
+  public void setEditable(boolean b)
+    {
+     textArea.setEditable(b);
+     bt2.setEnabled(b);
+     bt3.setEnabled(b);  
+    }
   // Method to read text from file
-  private void ReadText()
+  private void readText()
     {
       String dtext = "";
       TextInputFile f = new TextInputFile(file);
@@ -127,12 +178,18 @@ public class DataFileEditorPanel extends JPanel implements ActionListener
       // add code here
     }
   // Method to save the text from  display to a specific file
-  private void SaveText()
+  private void saveText()
     {
       String dtext = textArea.getText();
       TextOutputFile f = new TextOutputFile(file);
       f.print(dtext);   
       f.close();   
+    }
+
+  //Method to get the color of the Panel
+  private Color getPanelColor()
+    {
+      return getBackground();
     } 
 }      
 
