@@ -6,12 +6,12 @@
  * Created: Thu Apr 29 15:20:17 1999
  *
  * @author Nathan Stevens
- * @version 0.3
+ * @version 0.4
  */
 import java.io.*;
 import java.rmi.*;
 
-public class MopacApp extends ChemAppThread
+public class MopacApp extends Thread
 {
   private String[] Jobs, Jobs2;
   private Process process;
@@ -39,7 +39,7 @@ public class MopacApp extends ChemAppThread
       startJob();
     }
 
-  synchronized private void startJob()
+  private void startJob()
     {
       if(Mode.equals("local"))
 	{
